==> apache-roller-6.0.2-rc2-source.tar.gz: roller-weblogger-6.0.2-source/app/src/main/java/org/apache/roller/weblogger/ui/core/security/RollerRememberMeAuthenticationProvider.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 *  contributor license agreements.  The ASF licenses this file to You
 * under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.  For additional information regarding
 * copyright in this work, please see the NOTICE file in the top level
 * directory of this distribution.
 */

package org.apache.roller.weblogger.ui.core.security;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.roller.weblogger.config.WebloggerConfig;
import org.springframework.security.authentication.RememberMeAuthenticationProvider;


public class RollerRememberMeAuthenticationProvider extends RememberMeAuthenticationProvider {
    private static final Log log = LogFactory.getLog(RollerRememberMeServices.class);


    public RollerRememberMeAuthenticationProvider() {
        log.debug("initializing: RollerRememberMeAuthenticationProvider");

        String key = WebloggerConfig.getProperty("rememberme.key", "springRocks");

        if ("springRocks".equals(key)) {
            throw new RuntimeException(
                "If remember-me is to be enabled, rememberme.key must be specified in the roller " +
                "properties file. Make sure it is a secret and make sure it is NOT springRocks");
        }
        setKey(key);

        log.debug("initialized: RollerRememberMeAuthenticationProvider with key: " + getKey());
    }
}

==> apache-roller-6.1.3-source.tar.gz: roller-weblogger-6.1.3-source/app/src/main/java/org/apache/roller/weblogger/ui/core/security/RollerRememberMeAuthenticationProvider.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 *  contributor license agreements.  The ASF licenses this file to You
 * under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.  For additional information regarding
 * copyright in this work, please see the NOTICE file in the top level
 * directory of this distribution.
 */

package org.apache.roller.weblogger.ui.core.security;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.roller.weblogger.config.WebloggerConfig;
import org.springframework.security.authentication.RememberMeAuthenticationProvider;


public class RollerRememberMeAuthenticationProvider extends RememberMeAuthenticationProvider {
    private static final Log log = LogFactory.getLog(RollerRememberMeAuthenticationProvider.class);


    public RollerRememberMeAuthenticationProvider() {
        
        super(WebloggerConfig.getProperty("rememberme.key", "springRocks"));
        
        log.debug("initializing: RollerRememberMeAuthenticationProvider");

        if (WebloggerConfig.getBooleanProperty("rememberme.enabled") && "springRocks".equals(getKey())) {
            throw new RuntimeException(
                "If remember-me is to be enabled, rememberme.key must be specified in the roller " +
                "properties file. Make sure it is a secret and make sure it is NOT springRocks");
        }

        log.debug("initialized: RollerRememberMeAuthenticationProvider with key: " + getKey());
    }
}
